LexErrorKind

Enum LexErrorKind 

pub enum LexErrorKind {
    InvalidDigit {
        digit: char,
        radix: u32,
        token: String,
    },
    CouldNotLex {
        content: String,
    },
    BidiOverride,
}
The kind of lexer error, carrying any structured data needed for diagnostics.

Variants



InvalidDigit

A digit was invalid for the given radix (e.g. 9 in an octal literal).

Fields

digit: char
radix: u32
token: String


CouldNotLex

A token could not be lexed at all.

Fields

content: String


BidiOverride

A Unicode bidi override code point was encountered.