Parse

Struct Parse 

pub struct Parse { /* private fields */ }
The result of a parse operation.

A parse result always contains a syntax tree, even if errors occurred. This is essential for IDE use cases where we need to provide feedback even on incomplete or invalid code.

Implementations

Source

impl Parse

pub fn syntax(&self) -> SyntaxNode

Get the root syntax node.

pub fn errors(&self) -> &[ParseError]

Get the parse errors.

pub fn is_ok(&self) -> bool

Check if the parse was successful (no errors).

pub fn ok(self) -> Result<SyntaxNode, Vec<ParseError>>

Convert to a Result, returning the syntax node on success or errors on failure.