pub struct Parse { /* private fields */ }Expand description
The result of a parse operation.
A parse result always contains a syntax tree, even if errors occurred. This is essential for IDE use cases where we need to provide feedback even on incomplete or invalid code.
Implementations
Sourceimpl Parse
impl Parse
Sourcepub fn syntax(&self) -> SyntaxNode
pub fn syntax(&self) -> SyntaxNode
Get the root syntax node.
Sourcepub fn errors(&self) -> &[ParseError]
pub fn errors(&self) -> &[ParseError]
Get the parse errors.
Sourcepub fn ok(self) -> Result<SyntaxNode, Vec<ParseError>>
pub fn ok(self) -> Result<SyntaxNode, Vec<ParseError>>
Convert to a Result, returning the syntax node on success or errors on failure.